Scriptname idek:uss:USSUpdateScript extends ReferenceAlias

GlobalVariable Property _USSVersion Auto Const Mandatory
GlobalVariable Property _USSVersionCurrent Auto Const Mandatory
GlobalVariable Property _USSDebugMode Auto Const Mandatory
Quest Property _USSReset Auto Const Mandatory
Quest Property _USSQuest Auto Const Mandatory
Message Property _USSMessageUpdate127 Auto Const Mandatory
Message Property _USSMessageUpdateGeneral Auto Const Mandatory
Message Property _USSMessageUpdateUnknown Auto Const Mandatory
Holotape Property _USSConfigHolotape Auto Const Mandatory

Event OnAliasReset()
	DoUpdate()
EndEvent

Event OnPlayerLoadGame()
	DoUpdate()
EndEvent

Function DoUpdate()
	float versionLast = _USSVersion.GetValue()
	float versionCurrent = _USSVersionCurrent.GetValue()
	
	if (versionCurrent != versionLast)
		
		if (_USSDebugMode.GetValue())
			Debug.MessageBox("USS running update script...\n\nLast version = " + versionLast + "\nCurrent version = " + versionCurrent)
		endif
	
		if (versionLast == 0)
			; queue a reset if necessary (this also runs on new games)
			Update140()
			Update145()
			_USSMessageUpdateGeneral.Show()
		elseif (versionLast == 1.4)
			; no need to do this for updates from 1.3.x or below, because a full reset triggers in that case anyway
			Update142()
			Update145()
			_USSMessageUpdateGeneral.Show()
		elseif (versionLast <= 1.44)
			Update145()
			_USSMessageUpdateGeneral.Show()
		elseif (versionLast < 1.5)
			; still 1.4.x, probably a minor update, so don't really do anything unless necessary
			Utility.Wait(5)
			_USSMessageUpdateGeneral.Show()
		else
			; version unrecognized - maybe downgrading?
			_USSMessageUpdateUnknown.Show()
		endif
		
		_USSVersion.SetValue(versionCurrent)
	endif
EndFunction

Function Update140()
	; last version installed = 1.3.1 or below, OR new install
	; detect if aliases are correctly filled, if not do a reset
	bool doReset = true
	ReferenceAlias workshopAlias
	int i = 1
	int filledCount = 0
	
	Utility.Wait(5)

	while (i <= 100 && doReset)
		workshopAlias = _USSQuest.GetAlias(i) as ReferenceAlias
		if (workshopAlias.GetReference() != None)
			filledCount += 1
		endif
		
		if filledCount > 25
			doReset = false
		endif

		i += 1
	endwhile

	if (doReset)
		_USSReset.Start()
		_USSMessageUpdate127.Show()
	endif
EndFunction

Function Update142()
	; added some extra pointers for speed in 1.4.2, so make sure those get filled or everything will be borked
	int i = 1
	idek:uss:USSScript USSScript
	ObjectReference workbench
	
	Utility.Wait(5)

	while (i <= 100)
		USSScript = _USSQuest.GetAlias(i) as idek:uss:USSScript
		workbench = USSScript.GetReference()
		if (workbench != None)
			USSScript.FillPointers()
		endif
		
		i += 1
	endwhile
EndFunction

Function Update145()
	; changed how holotape recovery works, so remove old ones from workbenches in case USS placed them everywhere
	int i = 1
	idek:uss:USSScript USSScript
	WorkshopScript wsScript
	ObjectReference workbench
	Utility.Wait(5)
	
	while (i <= 100)
		USSScript = _USSQuest.GetAlias(i) as idek:uss:USSScript
		wsScript = USSScript.GetReference() as WorkshopScript
		if (wsScript != None)
			workbench = wsScript.GetContainer()
			if (workbench != None)
				workbench.RemoveItem(_USSConfigHolotape, -1)
			endif
		endif
		
		i += 1
	endwhile
EndFunction
